summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/sqlwriter.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/sqlwriter.h')
-rw-r--r--umbrello/umbrello/codegenerators/sqlwriter.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/umbrello/umbrello/codegenerators/sqlwriter.h b/umbrello/umbrello/codegenerators/sqlwriter.h
index 42271af0..e4df5e2b 100644
--- a/umbrello/umbrello/codegenerators/sqlwriter.h
+++ b/umbrello/umbrello/codegenerators/sqlwriter.h
@@ -15,24 +15,25 @@
* *
***************************************************************************/
-#ifndef SQLWRITER_H
-#define SQLWRITER_H
+#ifndef STQLWRITER_H
+#define STQLWRITER_H
#include "simplecodegenerator.h"
#include "../umlattributelist.h"
/**
* class SQLWriter is a code generator for UMLClassifier objects.
* Create an instance of this class, and feed it a UMLClassifier when
* calling writeClass and it will generate a sql source file for
* that concept
*/
-class SQLWriter : public SimpleCodeGenerator {
+class STQLWriter : public SimpleCodeGenerator {
Q_OBJECT
+ TQ_OBJECT
public:
- SQLWriter();
- virtual ~SQLWriter();
+ STQLWriter();
+ virtual ~STQLWriter();
/**
* call this method to generate sql code for a UMLClassifier
@@ -74,4 +75,4 @@ private:
void printAttributes(TQTextStream& sql, UMLAttributeList attributeList, bool first);
};
-#endif // SQLWRITER_H
+#endif // STQLWRITER_H
@@ -15,24 +15,25 @@
#include "../umlattributelist.h"
/**
- * class SQLWriter is a code generator for UMLClassifier objects.
+ * class STQLWriter is a code generator for UMLClassifier objects.
* Create an instance of this class, and feed it a UMLClassifier when
* calling writeClass and it will generate a sql source file for